@@ -1,6 +1,8 @@
+__title__ = 'dash.discover'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
+__all__ = ('autodiscover',)
 
 import imp
 
